@@ -16,13 +16,17 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
-import os
-from pathlib import Path
-from typing import Any, Union
-import numpy as np
-import zlib
+
 import logging
-from .datatypes import Packing, Datatypes, np_dtypes
+import os
+import zlib
+from pathlib import Path
+from typing import Any
+
+import numpy as np
+import numpy.typing as npt
+
+from .datatypes import Datatypes, Packing, np_dtypes
 from .readheader import readheader, telldatainfo
 
 
@@ -38,7 +42,7 @@ class FliFile:
     - _di: dictionary with data information based on the header
     """
 
-    def __init__(self, filepath: Union[str, os.PathLike[Any]]) -> None:
+    def __init__(self, filepath: str | os.PathLike[Any]) -> None:
         # open file
         if isinstance(filepath, str):
             self.path = Path(filepath)
@@ -51,7 +55,7 @@ class FliFile:
         self.log = logging.getLogger("flifile")
         self.header, self._datastart = readheader(self.path)
         self.datainfo = telldatainfo(self.header)
-        self._bg = np.array([], dtype=self.datainfo.BGType.nptype)
+        self._bg: npt.NDArray[np_dtypes] = np.array([], dtype=self.datainfo.BGType.nptype)
 
     def getdata(
         self, subtractbackground: bool = True, squeeze: bool = True
@@ -70,7 +74,7 @@ class FliFile:
             fid = self.path.open(mode="rb")
             fid.seek(self._datastart)
             dcmp = zlib.decompressobj(32 + zlib.MAX_WBITS)  # skip the GZIP header
-            data = np.frombuffer(
+            data: npt.NDArray[np_dtypes] = np.frombuffer(
                 dcmp.decompress(fid.read()), dtype=self.datainfo.IMType.nptype
             )
             bg = data[datasize:]
@@ -82,7 +86,6 @@ class FliFile:
                 datatype=self.datainfo.IMType,
                 datasize=datasize,
             )
-
         if self.datainfo.IMType.bits == 12:  # 12 bit per pixel packed per 2 in 3 bytes
             data = self._convert_12_bit(data, datatype=self.datainfo.IMType)
         data = data.reshape(self.datainfo.IMSize[::-1])
@@ -96,12 +99,10 @@ class FliFile:
 
         return data
 
-    def getbackground(
-        self, squeeze: bool = True
-    ) -> np.ndarray[Any, np.dtype[np_dtypes]]:
+    def getbackground(self, squeeze: bool = True) -> np.ndarray[Any, np.dtype[np_dtypes]]:
         """
-        Returns the background data from the .fli file. If squeeze is False the data is retured with these dimensions:
-        frequency,time,phase,z,y,x,channel
+        Returns the background data from the .fli file. If squeeze is False the data is
+        returned with these dimensions: frequency,time,phase,z,y,x,channel
         :param squeeze: Return data without singleton dimensions in x,y,ph,t,z,fr,c order
         :return: numpy.ndarray
         """
@@ -120,19 +121,13 @@ class FliFile:
             else:
                 offset = (
                     self._datastart
-                    + (
-                        self.datainfo.IMType.bits
-                        * int(np.prod(self.datainfo.IMSize, dtype=np.uint64))
-                    )
-                    / 8
+                    + (self.datainfo.IMType.bits * int(np.prod(self.datainfo.IMSize, dtype=np.uint64))) / 8
                 )
                 datasize = int(np.prod(self.datainfo.BGSize, dtype=np.uint64))
                 data = self._get_data_from_file(
                     offset=int(offset), datatype=self.datainfo.BGType, datasize=datasize
                 )
-                if (
-                    self.datainfo.BGType.bits == 12
-                ):  # 12 bit per pixel packed per 2 in 3 bytes
+                if self.datainfo.BGType.bits == 12:  # 12 bit per pixel packed per 2 in 3 bytes
                     data = self._convert_12_bit(
                         data,
                         datatype=self.datainfo.BGType,
@@ -200,13 +195,9 @@ class FliFile:
             data[0::2] = byte1.astype(np.uint16) + np.left_shift(
                 np.left_shift(byte2, 4).astype(np.uint8).astype(np.uint16), 4
             )
-            data[1::2] = np.left_shift(byte3.astype(np.uint16), 4) + np.right_shift(
-                byte2, 4
-            ).astype(np.uint8)
+            data[1::2] = np.left_shift(byte3.astype(np.uint16), 4) + np.right_shift(byte2, 4).astype(np.uint8)
         elif datatype.packing == Packing.MSB:
-            data[0::2] = np.left_shift(byte1.astype(np.uint16), 4) + np.right_shift(
-                byte2, 4
-            ).astype(np.uint8)
+            data[0::2] = np.left_shift(byte1.astype(np.uint16), 4) + np.right_shift(byte2, 4).astype(np.uint8)
             data[1::2] = np.left_shift(
                 np.left_shift(byte2, 4).astype(np.uint8).astype(np.uint16), 4
             ) + byte3.astype(np.uint16)
@@ -220,10 +211,14 @@ class FliFile:
         if datatype.bits == 12:  # 12 bit per pixel packed per 2 in 3 bytes
             # e.g. if you would want to get 4 values, this is 48 bits, is 6 bytes.
             count = int(3 * (datasize / 2))
-            return np.fromfile(self.path, offset=offset, dtype=np.uint8, count=count)
-        return np.fromfile(
+            result12: npt.NDArray[np_dtypes] = np.fromfile(
+                self.path, offset=offset, dtype=np.uint8, count=count
+            )
+            return result12
+        result: npt.NDArray[np_dtypes] = np.fromfile(
             self.path, offset=offset, dtype=datatype.nptype, count=datasize
         )
+        return result
 
     def __str__(self) -> str:
         return self.path.name
