@@ -2,7 +2,8 @@ import os
 from collections import deque
 from dataclasses import dataclass
 from pathlib import Path
-from typing import Dict, Union, Any, BinaryIO, Tuple
+from typing import Any, BinaryIO
+
 from flifile.datatypes import Datatypes, getdatatype
 
 
@@ -22,8 +23,8 @@ def readheadersize(f: BinaryIO) -> int:
 
 
 def readheader(
-    file: Union[str, os.PathLike[Any]]
-) -> Tuple[dict[str, Dict[str, Dict[str, str]]], int]:
+    file: str | os.PathLike[Any],
+) -> tuple[dict[str, dict[str, dict[str, str]]], int]:
     file = Path(file)
     with file.open(mode="rb") as f:
         s = readheadersize(f)
@@ -32,10 +33,10 @@ def readheader(
         return h, s
 
 
-def parseheader(headerstring: bytes) -> Dict[str, Dict[str, Dict[str, str]]]:
+def parseheader(headerstring: bytes) -> dict[str, dict[str, dict[str, str]]]:
     chapter = "DEFAULT"
     section = "DEFAULT"
-    header: Dict[str, Dict[str, Dict[str, str]]] = {}
+    header: dict[str, dict[str, dict[str, str]]] = {}
     for line in headerstring.split(b"\n"):
         if line.startswith(b"{"):
             chapter = line.decode("utf-8").strip()[1:-1]
@@ -45,34 +46,29 @@ def parseheader(headerstring: bytes) -> Dict[str, Dict[str, Dict[str, str]]]:
             kvp = line.split(b"=")
             if len(kvp) != 2:
                 continue
-            if chapter not in header.keys():
+            if chapter not in header:
                 header[chapter] = {}
             if section not in header[chapter]:
                 header[chapter][section] = {}
-            header[chapter][section][kvp[0].decode("utf-8").strip()] = (
-                kvp[1].decode("utf-8").strip()
-            )
+            header[chapter][section][kvp[0].decode("utf-8").strip()] = kvp[1].decode("utf-8").strip()
     return header
 
 
-def tellversion(header: Dict[str, Dict[str, Dict[str, str]]]) -> str:
+def tellversion(header: dict[str, dict[str, dict[str, str]]]) -> str:
     version = ""
-    if "FLIMIMAGE" in header:  # for version 1
-        if "INFO" in header["FLIMIMAGE"]:
-            version = header["FLIMIMAGE"]["INFO"].get("version", "")
-            if version:
-                return version
+    if ("FLIMIMAGE" in header) & ("INFO" in header["FLIMIMAGE"]):  # for version 1
+        version = header["FLIMIMAGE"]["INFO"].get("version", "")
+        if version:
+            return version
 
-    if "FLIMIMAGE" in header:  # for version 2
-        if "DEFAULT" in header["FLIMIMAGE"]:
-            version = header["FLIMIMAGE"]["DEFAULT"].get("version", "")
-            if version:
-                return version
-    if "DEFAULT" in header:  # for version 2 if the chapter is gone.
-        if "DEFAULT" in header["DEFAULT"]:
-            version = header["DEFAULT"]["DEFAULT"].get("version", "")
-            if version:
-                return version
+    if ("FLIMIMAGE" in header) & ("DEFAULT" in header["FLIMIMAGE"]):  # for version 2
+        version = header["FLIMIMAGE"]["DEFAULT"].get("version", "")
+        if version:
+            return version
+    if ("DEFAULT" in header) & ("DEFAULT" in header["DEFAULT"]):  # for version 2 if the chapter is gone.
+        version = header["DEFAULT"]["DEFAULT"].get("version", "")
+        if version:
+            return version
     return version
 
 
@@ -91,7 +87,7 @@ class DataInfo:
         return self.valid
 
 
-def telldatainfo(header: Dict[str, Dict[str, Dict[str, str]]]) -> DataInfo:
+def telldatainfo(header: dict[str, dict[str, dict[str, str]]]) -> DataInfo:
     version = tellversion(header)
     imsize = (0, 0, 0, 0, 0, 0, 0)
     imtype = Datatypes.UINT8
@@ -145,9 +141,7 @@ def telldatainfo(header: Dict[str, Dict[str, Dict[str, str]]]) -> DataInfo:
     elif version == "2.0":
         ch = len(header["FLIMIMAGE"]["DEFAULT"]["channels"].strip("{}[]").split(","))
         ph = len(header["FLIMIMAGE"]["DEFAULT"]["phases"].strip("{}[]").split(","))
-        ts = len(
-            header["FLIMIMAGE"]["DEFAULT"]["timestamps"].strip("{}[]").split(",")
-        )  # seems unused
+        _ = len(header["FLIMIMAGE"]["DEFAULT"]["timestamps"].strip("{}[]").split(","))  # seems unused
         fr = len(header["FLIMIMAGE"]["DEFAULT"]["frequencies"].strip("{}[]").split(","))
         imsize = (
             ch,
